<?php

// Buttons
$lang['save_btn'] = 'Сохранить';
$lang['cancel_btn'] = 'Отменить';
$lang['delete_btn'] = 'Удалить';
$lang['change_btn'] = 'Редактировать';
$lang['add_to_panel_btn'] = 'Добавить на панель быстрого запуска';

// Pages
$lang['page_admin'] = 'Админ панель';

// Message
$lang['msg_head_error'] = 'ошибка';
$lang['msg_access_denied'] = 'У вас недостаточно прав! Ви можете:';
$lang['msg_back'] = 'Вернуться на предыдущую страницу';
$lang['msg_relogin'] = 'Авторизоваться снова';
$lang['no data found'] = 'Нет событий для отображения';
$lang['Warning! Project is in development mode'] = '<b>Внимание!</b> Проект в режиме "development".';

// Menu
$lang['menu_back_text'] = '<span>«</span>Назад';
$lang['menu_next_text'] = 'Вперед';
$lang['menu_title'] = 'Меню';
$lang['home_btn'] = 'Домой';
$lang['site_btn'] = 'На сайт';
$lang['exit_btn'] = 'Выйти';

// menu blocks
$lang['block_up_text'] = 'свернуть';
$lang['block_down_text'] = 'развернуть';

// search menu
$lang['search_text'] = 'поиск ...';
$lang['search_title'] = 'Результаты поиска:';

$lang['active'] = 'Да';
$lang['no_active'] = 'Нет';

$lang['Translate manager'] = 'Менеджер переводов';
$lang['Translations was saved'] = 'Переводы сохранены';
$lang['For example'] = 'Например';
$lang['Set default text'] = 'Установить текст по умолчанию';
$lang['File imported. Records count %s. Please, check and save changes.'] = 'Файл импортирован. Количество записей %s. Пожалуйста, проверьте и сохраните изменения.';
$lang['Keys'] = 'Ключи';
$lang['Translation key'] = 'Ключ перевода';
$lang['Example'] = 'Пример';